@@ -7,6 +7,7 @@ class ConfigSchema(Schema):
     Attributes:
         address (str): Instance address, e.g. https://my_instance.service-now.com
         basic_auth (tuple): (<username>, <password>), mutually exclusive with other authentication methods
+        verify_ssl (bool): Whether to validate SSL certificates, defaults to True
     """
 
     class InternalConfig:
@@ -18,6 +19,7 @@ class ConfigSchema(Schema):
 
     address = fields.Url(required=True)
     basic_auth = fields.Tuple(tuple_fields=(fields.String(), fields.String()), required=False)
+    verify_ssl = fields.Boolean(missing=True)
 
     def __init__(self, *args, **kwargs):
         super(ConfigSchema, self).__init__(*args, **kwargs)
